.. flippers documentation master file, created by
   sphinx-quickstart on Sun Mar 26 01:49:07 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

#######################
flippers Documentation
#######################


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   pages/installation
   pages/overview
   pages/related

.. toctree::
   :maxdepth: 2
   :caption: Applications

   apps/notebook
   apps/console
   apps/preview
   apps/hub

.. toctree::
   :maxdepth: 2
   :caption: API Reference
   :hidden:

   reference/flippers

******************
Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`